@@ -30,7 +30,7 @@ ecospat.Epred <- function(x, w = rep(1, ncol(x)), th = 0) {
   Ebin <- function(vect2bin) {
     th <- vect2bin[1]
     vec <- vect2bin[-1]
-    return(BinaryTransformation(vec, th))
+    return(bm_BinaryTransformation(vec, th))
   }
 
   if (th != 0) {
@@ -69,7 +69,7 @@ dsg <- function(data.coor, mindist) {
 }
 
 pod <- function(fit, obs, th) {
-  fitbin <- 2 * BinaryTransformation(fit, th)
+  fitbin <- 2 * bm_BinaryTransformation(fit, th)
   return(length(which((fitbin + obs) == 3))/length(which(obs == 1)))
 }
 
@@ -183,4 +183,4 @@ ecospat.npred <- function(x, th) {
     xi <- xi[, -narank]
   }
   return(dim(xi)[1])
-}
\ No newline at end of file
+}
