@@ -1,11 +1,12 @@
 # @ ecospat.rcls.grd This function was written by Achilleas Psomas for reclassifying grids
 # The purpose is to get a combined statification from more than one grid
 # written by achilleas.psomas@wsl.ch
+# adapted by Flavien Collart
 
 ### THIS FUNCTION REQUIRES THAT THE PACKAGE 'classInt' is installed
 
 ecospat.rcls.grd <- function(in_grid, no.classes) {
-  new_classes <- classIntervals(getValues(in_grid), no.classes, style = "equal")
+  new_classes <- classInt::classIntervals(na.omit(terra::values(in_grid)), no.classes, style = "equal")
   # new_classes <-classIntervals(getValues(in_grid), no.classes , style = 'sd')
   new_classes_breaks <- new_classes$brks
   new_classes_limits <- matrix(ncol = 3, nrow = no.classes)
@@ -15,7 +16,7 @@ ecospat.rcls.grd <- function(in_grid, no.classes) {
     new_classes_limits[i, 2] <- new_classes_breaks[i + 1]
     new_classes_limits[i, 3] <- classes[i]
   }
-  in_grid_reclass <- reclassify(in_grid, new_classes_limits, include.lowest = TRUE)
+  in_grid_reclass <- terra::classify(in_grid, new_classes_limits, include.lowest = TRUE)
   return(in_grid_reclass)
 }
 
@@ -40,12 +41,12 @@ ecospat.rcls.grd <- function(in_grid, no.classes) {
 # ---------------------------------------------------------------------------#
 
 ecospat.recstrat_prop <- function(in_grid, sample_no) {
-  strata <- na.omit(unique(getValues(in_grid)))
+  strata <- as.numeric(na.omit(unique(terra::values(in_grid))))
   strata_no <- length(strata)
-  in_grid_SPixels <- as(in_grid, "SpatialPointsDataFrame")
-  total_pixels <- nrow(in_grid_SPixels@data)
+  in_grid_SPixels <- terra::as.points(in_grid)
+  total_pixels <- nrow(in_grid_SPixels)
 
-  strata_stats <- table(in_grid_SPixels$layer)
+  strata_stats <- table(in_grid_SPixels[[1]])
 
   strata_stats_sorted <- as.data.frame(sort(strata_stats, decreasing = TRUE))
   pixels_largest_strata <- max(strata_stats_sorted$Freq)
@@ -53,12 +54,14 @@ ecospat.recstrat_prop <- function(in_grid, sample_no) {
 
   result_list <- list()
   for (j in 1:length(strata)) {
-    grid_sel <- in_grid_SPixels[in_grid_SPixels@data[, 1] == strata[j], ]
-    proportion <- ceiling(log(dim(grid_sel@data)[1])/log(pixels_largest_strata) * proportion_largest_strata)
-
-    optimal_samples_per_class <- ifelse(proportion < dim(grid_sel@data)[1], proportion, dim(grid_sel@data)[1])
+    grid_sel <- in_grid_SPixels[in_grid_SPixels[[1]] == strata[j], ]
+    proportion <- ceiling(log(nrow(grid_sel))/log(pixels_largest_strata) * proportion_largest_strata)
+    if(proportion==0){ ##Avoid Warnings
+      next
+    }
+    optimal_samples_per_class <- ifelse(proportion < nrow(grid_sel), proportion, nrow(grid_sel))
     sp_points <- grid_sel[sample(1:nrow(grid_sel), optimal_samples_per_class, replace = FALSE), ]
-    sample_points <- cbind(sp_points@coords, class = sp_points@data[, 1])
+    sample_points <- cbind(terra::crds(sp_points), class = strata[j])
     result_list[[j]] <- sample_points
   }
   result <- data.frame(do.call("rbind", result_list))
@@ -86,7 +89,7 @@ ecospat.recstrat_prop <- function(in_grid, sample_no) {
   # -------------------------------------------------------------------- #
 
 ecospat.recstrat_regl <- function(in_grid, sample_no) {
-  strata <- na.omit(unique(getValues(in_grid)))
+  strata <- as.numeric(na.omit(unique(terra::values(in_grid))))
   strata_no <- length(strata)
   if (sample_no < strata_no) {
     stop("Stoping Execution: The number of samples is lower the total number of unique classes")
@@ -94,17 +97,18 @@ ecospat.recstrat_regl <- function(in_grid, sample_no) {
     samples_per_class <- round(sample_no/strata_no)
   }
 
-  in_grid_SPixels <- as(in_grid, "SpatialPointsDataFrame")
+  in_grid_SPixels <-  terra::as.points(in_grid)
 
   result_list <- list()
   for (j in 1:length(strata)) {
-    grid_sel <- in_grid_SPixels[in_grid_SPixels@data[, 1] == strata[j], ]
-    optimal_samples_per_class <- ifelse(dim(grid_sel@data)[1] > samples_per_class, samples_per_class,
-      dim(grid_sel@data)[1])
+    grid_sel <- in_grid_SPixels[in_grid_SPixels[[1]] == strata[j], ]
+    lon <- nrow(grid_sel)
+    optimal_samples_per_class <- ifelse(lon > samples_per_class, samples_per_class,
+      lon)
     sp_points <- grid_sel[sample(1:nrow(grid_sel), optimal_samples_per_class, replace = FALSE), ]
-    result_list[[j]] <- cbind(sp_points@coords, sp_points@data)
+    result_list[[j]] <- cbind(terra::crds(sp_points), class = strata[j])
   }
   result <- do.call("rbind", result_list)
   names(result) <- c("x", "y", "class")
   return(result)
-}
\ No newline at end of file
+}
